@@ -30,11 +30,10 @@
 
 #include "gsm-inhibitor.h"
 #include "gsm-inhibitor-glue.h"
+#include "gsm-util.h"
 
 static guint32 inhibitor_serial = 1;
 
-#define IS_STRING_EMPTY(x) ((x)==NULL||(x)[0]=='\0')
-
 #define GSM_INHIBITOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_INHIBITOR, GsmInhibitorPrivate))
 
 struct GsmInhibitorPrivate
@@ -143,7 +142,7 @@ gsm_inhibitor_constructor (GType                  type,
                                                                                              construct_properties));
 
         g_free (inhibitor->priv->id);
-        inhibitor->priv->id = g_strdup_printf ("/org/mate/SessionManager/Inhibitor%u", get_next_inhibitor_serial ());
+        inhibitor->priv->id = g_strdup_printf ("/org/gnome/SessionManager/Inhibitor%u", get_next_inhibitor_serial ());
         res = register_inhibitor (inhibitor);
         if (! res) {
                 g_warning ("Unable to register inhibitor with session bus");
